SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

DROP SCHEMA IF EXISTS `pelutfc` ;
CREATE SCHEMA IF NOT EXISTS `pelutfc` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `pelutfc` ;

-- -----------------------------------------------------
-- Table `pelutfc`.`USUARI`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`USUARI` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`USUARI` (
  `LOGIN` VARCHAR(32) NOT NULL ,
  `CONTRASENYA` VARCHAR(64) NOT NULL ,
  `ROL` VARCHAR(32) NOT NULL ,
  `NOM` VARCHAR(64) NOT NULL ,
  `COGNOM1` VARCHAR(64) NOT NULL ,
  `COGNOM2` VARCHAR(64) NULL ,
  `TELEFON` VARCHAR(9) NOT NULL ,
  `CORREU` VARCHAR(128) NULL ,
  `DATA` DATETIME NULL ,
  `CATEGORIA` VARCHAR(64) NULL ,
  `SOU` FLOAT NULL ,
  `ACTIU` TINYINT(1) NOT NULL DEFAULT 1 ,
  PRIMARY KEY (`LOGIN`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`VENDA`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`VENDA` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`VENDA` (
  `ID` INT NOT NULL ,
  `DATA` DATETIME NOT NULL ,
  `NOM` VARCHAR(45) NULL DEFAULT 'VENTA' ,
  `QUANTITAT` FLOAT NOT NULL ,
  `CLIENT` VARCHAR(32) NOT NULL ,
  `PERRUQUER` VARCHAR(32) NOT NULL ,
  PRIMARY KEY (`ID`) ,
  INDEX `fk_VENDA_USUARI1_idx` (`CLIENT` ASC) ,
  INDEX `fk_VENDA_USUARI2_idx` (`PERRUQUER` ASC) ,
  CONSTRAINT `fk_VENDA_USUARI1`
    FOREIGN KEY (`CLIENT` )
    REFERENCES `pelutfc`.`USUARI` (`LOGIN` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_VENDA_USUARI2`
    FOREIGN KEY (`PERRUQUER` )
    REFERENCES `pelutfc`.`USUARI` (`LOGIN` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`CITA`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`CITA` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`CITA` (
  `ID` INT NOT NULL ,
  `DATA` DATETIME NOT NULL ,
  `VENDA` INT NULL ,
  `CLIENT` VARCHAR(32) NOT NULL ,
  `PERRUQUER` VARCHAR(32) NOT NULL ,
  `DESCRIPCIO` VARCHAR(256) NULL ,
  PRIMARY KEY (`ID`) ,
  INDEX `fk_CITA_VENTA1_idx` (`VENDA` ASC) ,
  INDEX `fk_CITA_USUARI1_idx` (`CLIENT` ASC) ,
  INDEX `fk_CITA_USUARI2_idx` (`PERRUQUER` ASC) ,
  CONSTRAINT `fk_CITA_VENTA1`
    FOREIGN KEY (`VENDA` )
    REFERENCES `pelutfc`.`VENDA` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CITA_USUARI1`
    FOREIGN KEY (`CLIENT` )
    REFERENCES `pelutfc`.`USUARI` (`LOGIN` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CITA_USUARI2`
    FOREIGN KEY (`PERRUQUER` )
    REFERENCES `pelutfc`.`USUARI` (`LOGIN` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`SERVEI`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`SERVEI` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`SERVEI` (
  `ID` INT NOT NULL ,
  `NOM` VARCHAR(45) NOT NULL ,
  `DESCRIPCIO` VARCHAR(128) NULL ,
  `PREU` FLOAT NOT NULL ,
  `ACTIU` TINYINT(1) NOT NULL DEFAULT 1 ,
  PRIMARY KEY (`ID`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`PRODUCTE`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`PRODUCTE` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`PRODUCTE` (
  `ID` INT NOT NULL ,
  `NOM` VARCHAR(45) NOT NULL ,
  `DESCRIPCIO` VARCHAR(128) NULL ,
  `PVP` FLOAT NOT NULL ,
  `PREUCOMPRA` FLOAT NOT NULL ,
  `UNITATS` INT NOT NULL DEFAULT 0 ,
  `PUBLIC` TINYINT(1) NOT NULL DEFAULT 1 ,
  `ACTIU` TINYINT(1) NOT NULL DEFAULT 1 ,
  PRIMARY KEY (`ID`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`GASTO`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`GASTO` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`GASTO` (
  `ID` INT NOT NULL ,
  `NOM` VARCHAR(45) NOT NULL ,
  `DESCRIPCIO` VARCHAR(128) NULL ,
  `DATA` DATETIME NOT NULL ,
  `QUANTITAT` FLOAT NOT NULL ,
  PRIMARY KEY (`ID`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`SERVEIS_USATS`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`SERVEIS_USATS` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`SERVEIS_USATS` (
  `VENDA` INT NOT NULL ,
  `SERVEI` INT NOT NULL ,
  `UNITATS` INT NOT NULL ,
  PRIMARY KEY (`VENDA`, `SERVEI`) ,
  INDEX `fk_VENTA_has_SERVEI_SERVEI1_idx` (`SERVEI` ASC) ,
  INDEX `fk_VENTA_has_SERVEI_VENTA1_idx` (`VENDA` ASC) ,
  CONSTRAINT `fk_VENTA_has_SERVEI_VENTA1`
    FOREIGN KEY (`VENDA` )
    REFERENCES `pelutfc`.`VENDA` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_VENTA_has_SERVEI_SERVEI1`
    FOREIGN KEY (`SERVEI` )
    REFERENCES `pelutfc`.`SERVEI` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`PRODUCTES_USATS`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`PRODUCTES_USATS` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`PRODUCTES_USATS` (
  `VENDA` INT NOT NULL ,
  `PRODUCTE` INT NOT NULL ,
  `UNITATS` INT NOT NULL ,
  PRIMARY KEY (`VENDA`, `PRODUCTE`) ,
  INDEX `fk_VENTA_has_PRODUCTE_PRODUCTE1_idx` (`PRODUCTE` ASC) ,
  INDEX `fk_VENTA_has_PRODUCTE_VENTA1_idx` (`VENDA` ASC) ,
  CONSTRAINT `fk_VENTA_has_PRODUCTE_VENTA1`
    FOREIGN KEY (`VENDA` )
    REFERENCES `pelutfc`.`VENDA` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_VENTA_has_PRODUCTE_PRODUCTE1`
    FOREIGN KEY (`PRODUCTE` )
    REFERENCES `pelutfc`.`PRODUCTE` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pelutfc`.`PRODUCTES_VENUTS`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `pelutfc`.`PRODUCTES_VENUTS` ;

CREATE  TABLE IF NOT EXISTS `pelutfc`.`PRODUCTES_VENUTS` (
  `VENDA` INT NOT NULL ,
  `PRODUCTE` INT NOT NULL ,
  `UNITATS` INT NOT NULL ,
  PRIMARY KEY (`VENDA`, `PRODUCTE`) ,
  INDEX `fk_VENTA_has_PRODUCTE1_PRODUCTE1_idx` (`PRODUCTE` ASC) ,
  INDEX `fk_VENTA_has_PRODUCTE1_VENTA1_idx` (`VENDA` ASC) ,
  CONSTRAINT `fk_VENTA_has_PRODUCTE1_VENTA1`
    FOREIGN KEY (`VENDA` )
    REFERENCES `pelutfc`.`VENDA` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_VENTA_has_PRODUCTE1_PRODUCTE1`
    FOREIGN KEY (`PRODUCTE` )
    REFERENCES `pelutfc`.`PRODUCTE` (`ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

USE `pelutfc` ;

-- -----------------------------------------------------
-- Placeholder table for view `pelutfc`.`LLISTAPREUSVIEW`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `pelutfc`.`LLISTAPREUSVIEW` (`ID` INT, `NOM` INT, `DESCRIPCIO` INT, `TIPUS` INT, `PREU` INT);

-- -----------------------------------------------------
-- Placeholder table for view `pelutfc`.`GASTOBENEFICIVIEW`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `pelutfc`.`GASTOBENEFICIVIEW` (`ID` INT, `TIPUS` INT, `NOM` INT, `DATA` INT, `QUANTITAT` INT);

-- -----------------------------------------------------
-- View `pelutfc`.`LLISTAPREUSVIEW`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `pelutfc`.`LLISTAPREUSVIEW` ;
DROP TABLE IF EXISTS `pelutfc`.`LLISTAPREUSVIEW`;
USE `pelutfc`;
CREATE  OR REPLACE VIEW `pelutfc`.`LLISTAPREUSVIEW` AS
SELECT ID, NOM, DESCRIPCIO, 'SERVEI' AS TIPUS, PREU FROM SERVEI WHERE ACTIU = '1'
UNION
SELECT ID, NOM, DESCRIPCIO, 'PRODUCTE' AS TIPUS, PVP AS PREU FROM PRODUCTE WHERE PUBLIC = '1' AND ACTIU = '1';
;

-- -----------------------------------------------------
-- View `pelutfc`.`GASTOBENEFICIVIEW`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `pelutfc`.`GASTOBENEFICIVIEW` ;
DROP TABLE IF EXISTS `pelutfc`.`GASTOBENEFICIVIEW`;
USE `pelutfc`;
CREATE  OR REPLACE VIEW `pelutfc`.`GASTOBENEFICIVIEW` AS
SELECT ID, 'GASTO' AS TIPUS, NOM, DATA, QUANTITAT FROM GASTO
UNION
SELECT ID, 'BENEFICI' AS TIPUS, NOM, DATA, QUANTITAT FROM VENDA;

SET SQL_MODE = '';
GRANT USAGE ON *.* TO admin;
 DROP USER admin;
SET SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';
CREATE USER 'admin' IDENTIFIED BY 'pelutfc';

GRANT ALL ON `pelutfc`.* TO 'admin';

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

